@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Schema::Translate;
 use vars '$VERSION';
-$VERSION = '0.89';
+$VERSION = '0.90';
 
 
 # Errors are either in _class 'usage': called with request
@@ -792,6 +792,7 @@ sub particleElement($)
 sub keyRewrite($)
 {   my ($self, $label) = @_;
     my ($ns, $key) = unpack_type $label;
+    my $oldkey = $key;
 
     foreach my $r ( @{$self->{rewrite}} )
     {   if(ref $r eq 'HASH')
@@ -832,10 +833,9 @@ sub keyRewrite($)
         }
     }
 
-    return (unpack_type $label)[1]
-        if $label eq $key;
+    trace "rewrote key $label to $key"
+        if $key ne $oldkey;
 
-    trace "rewrote key $label to $key";
     $key;
 }
 
@@ -894,7 +894,6 @@ sub attributeOne($)
         $form       = $node->getAttribute('form');
         $type       = $self->simpleType($tree->descend);
     }
-
     else
     {   $name       = $node->getAttribute('name')
             or error __x"attribute without name or ref at {where}"
