@@ -5,7 +5,7 @@
 
 package XML::Compile::Schema::XmlWriter;
 use vars '$VERSION';
-$VERSION = '0.89';
+$VERSION = '0.90';
 
 
 use strict;
@@ -269,19 +269,8 @@ sub element_handler
     return $optional
         if $min==0 && $max==1;
 
-    if($min==1 && $max==1)
-    {   return
-        sub { my ($doc, $values) = @_;
-              my @values = ref $values eq 'ARRAY' ? @$values
-                         : defined $values ? $values : ();
-
-              error __x"exactly one value needed for `{tag}', not {count} at {path}"
-                , tag => $label, count => scalar @values, path => $path
-                    if @values > 1;
-
-              $required->($doc, $values[0]);
-            };
-    }
+    return $required
+        if $min==1 && $max==1;
 
     my $opt = $max - $min;
     sub { my ($doc, $values) = @_;
@@ -465,8 +454,9 @@ sub complex_element
                 or error __x"complex `{tag}' requires data at {path}"
                       , tag => $tag, path => $path;
 
+warn "$data is no HASH" unless ref $data eq 'HASH';
             error __x"complex `{tag}' requires a HASH of input data, not `{found}' at {path}"
-               , tag => $tag, found => $data, path => $path;
+               , tag => $tag, found => (ref $data || $data), path => $path;
         }
 
         my $copy   = { %$data };  # do not destroy caller's hash
